/* REXX */

/*
 * EPAD. This file was originally created by Konstantin Kozlov
 * with Project Smarts on 6 Mar 2007.
 */

/*  REXX - EPAD install script                        */
/*  Installs EPAD's DLL                               */

Parse source . . __rexx_name;
__rexx_dir = Filespec('D',__rexx_name)||Filespec('P',__rexx_name)

Call RxFuncAdd 'SysLoadFuncs', 'REXXUTIL', 'SysLoadFuncs';
Call SysLoadFuncs;

   /* Check system drive */
   If \Rxfuncquery('SysBootDrive') Then
      system_drive = SysBootDrive()
   else
   do
      system_drive=FileSpec('Drive',Value('SYSTEM_INI',,'OS2ENVIRONMENT'))
      if system_drive = '' then
      do
         errmsg='Can not detect system drive. Please update REXXUTIL.DLL.'
         signal error
      end
   end

       tmpdir = STRIP(VALUE('TMP',,'OS2ENVIRONMENT'));
       if tmpdir='' THEN
          tmpdir = STRIP(VALUE('TEMP',,'OS2ENVIRONMENT'));

       bigicons = STRIP(VALUE('BIGICONS',,'OS2ENVIRONMENT'))
       /* OS directory */
       osdir = STRIP(VALUE('OSDIR',,'OS2ENVIRONMENT'))
       if osdir='' then
       do
               say 'IBM OS/2 or eComStation 1.0 detected'
               OS="OS2"
               osdir=system_drive||'\OS2'
               nlspath=osdir||'\DLL'
               if bigicons='' then
                  bigicons=osdir||'\BIGICONS'
       end
       else
       do
               say 'eComStation 1.1 or higher detected'
               OS="ECS"
               nlspath=osdir||'\LANG'
               if bigicons='' then
                  bigicons=osdir||'\icons\BIGICONS'
       end

     SAY "Please, select:"
     SAY "I - Install"
     SAY "U - Uninistall"

     PULL ACTION
     IF LEFT(ACTION, 1)='U' THEN
     DO
        SAY "You are about to uninstall EPAD class. This will delete all the PianoPad objects in the system!"
        SAY "Make sure You backed up Your PianoPad objects with BACKUP.CMD!"
        SAY "Do You want to continue with uninstall? (Y/N)"
        PULL ANSWER
        IF LEFT(ANSWER, 1)<>'Y' THEN
           EXIT
     END

     /* Get path for a file to store object settings */
     config=system_drive||'\config.sys'
     /* Get system DLL directory path */
     system_dll=osdir||'\DLL'
     system_hlp=osdir||'\HELP'

     say "Path for NLS: "||nlspath
     say "Path for the class DLL: "||system_dll
     say "Path for the help files: "||system_hlp
     say "Path for big icons: "||bigicons

        rc=SysDestroyObject('<PIANOPAD>');                /* Destroy PianoPad object */
        IF rc<>1 THEN
             Say  "PIANOPAD: Could not destroy object!, rc="rc".";

        rc=SysDeregisterObjectClass('EPAD');      /* Deregister EPAD class */
        IF rc<>1 THEN
             Say  "PIANOPAD: Could not deregister WPS class "EPAD"!, rc="rc".";

        rc=SysFileDelete(system_hlp||'\PianoPad.HLP');
        IF rc>2 THEN
           SAY 'Could not delete "' || system_hlp || '\PianoPad.HLP": ' || ERRORTEXT(rc)

        rc=SysFileDelete(system_hlp||'\Piano_ru.HLP');
        IF rc>2 THEN
           SAY 'Could not delete "' || system_hlp || '\PianoPad.HLP": ' || ERRORTEXT(rc)

        rc=SysFileDelete(nlspath||'\PianoPad.nls');
        IF rc>0 THEN
           SAY 'Could not delete "' || system_hlp || '\PianoPad.HLP": ' || ERRORTEXT(rc)

        rc=SysFileDelete(system_dll||'\PIANOPAD.DLL');
        IF rc>2 THEN
        DO
           SAY 'Could not delete "' || system_dll || '\PIANOPAD.DLL": ' || ERRORTEXT(rc)
           SAY "Please, restart WPS then try again."
           EXIT;
        END

     if (ACTION='I') THEN
     DO
        SAY Installing...
        Address CMD '@COPY '__rexx_dir'PIANOPAD.DLL 'system_dll '>>NUL'; /* Copy new DLL to system DLL dir */
        Address CMD '@COPY '__rexx_dir'\HLP\*.HLP 'system_hlp '>>NUL'; /* Copy new HLP to system HELP dir */
        Address CMD '@COPY '__rexx_dir'PIANOPAD.NLS 'nlspath '>>NUL'; /* Copy new NLS to system DLL dir */

        /* Everything OK so far.  Register EPAD class */
        rc=SysRegisterObjectClass('EPAD',system_dll||'\PIANOPAD.DLL');

        If rc <> 1 THEN                /* If EPAD class did not register OK */
        DO
           Say  "PIANOPAD: could not register EPAD class! Please, make sure, that LANGE library installed correctly!";
           Exit;
        END

        Address CMD '@XCOPY '__rexx_dir'BIGICONS\* 'bigicons'\ /S >>NUL';

        BIGICONS_PRESENT='NO'
        LAST_LINE_EMPTY='NO'
        rc=SysFileSearch('SET BIGICONS=', config, 'file.', 'N');
       if (rc) THEN
           SAY 'SysFileSearch returned: ' || ERRORTEXT(rc)
       else
       do i=1 to file.0
           PARSE VAR file.i LINE_NUMBER SET VARIABLE '=' VALUE
           if SET='SET' & VARIABLE='BIGICONS' then
              BIGICONS_PRESENT='YES'
       end

        IF BIGICONS_PRESENT='NO' THEN
        DO
           SAY 'Updating "'||config||'"...'
           rc=LINEOUT(config,'');
           rc=LINEOUT(config, 'SET BIGICONS='||bigicons);
        END

        If rc > 0 THEN                /* If there were create errors */
           Say  "Failed!, rc="rc".";
        else
           Say  "Done!";

        SAY "Installation successful!"
        SAY "Do You want to create a default PianoPad object on the desktop? (Y/N)"
        PULL ANSWER
        IF LEFT(ANSWER, 1)='Y'
        THEN
           CALL CREATE.CMD
        ELSE
        DO
           SAY "Now You can either use CREATE.CMD to create a PianoPad object on the Desktop,"
           SAY "or RESTORE.CMD to restore Your PianoPAd objects, saved with BACKUP.CMD"
        END
     END
Exit;
